@@ -16,7 +16,6 @@ import fixtures
 from keystoneauth1 import fixture as client_fixtures
 from oslo_log import log as logging
 from oslo_utils import timeutils
-from positional import positional
 
 from keystonemiddleware import auth_token
 from keystonemiddleware.auth_token import _exceptions
@@ -43,7 +42,6 @@ class AuthTokenFixture(fixtures.Fixture):
     def tokens(self):
         return self._token_data.keys()
 
-    @positional(1)
     def add_token_data(self, token_id=None, expires=None,
                        user_id=None, user_name=None,
                        user_domain_id=None, user_domain_name=None,
@@ -73,7 +71,6 @@ class AuthTokenFixture(fixtures.Fixture):
             token.add_role(name=role)
         self.add_token(token, token_id=token_id)
 
-    @positional()
     def add_token(self, token_data, token_id=None):
         """Add an existing token to the middleware.
 
