@@ -65,26 +65,8 @@ class S3Token(object):
         self._reseller_prefix = conf.get('reseller_prefix', 'AUTH_')
         # where to find the auth service (we use this to validate tokens)
 
-        self._request_uri = conf.get('www_authenticate_uri')
-        auth_uri = conf.get('auth_uri')
-        if not self._request_uri and auth_uri:
-            self._logger.warning(
-                "Use of the auth_uri option was deprecated "
-                "in the Queens release in favor of www_authenticate_uri. This "
-                "option will be removed in the S release.")
-            self._request_uri = auth_uri
-        if not self._request_uri:
-            self._logger.warning(
-                "Use of the auth_host, auth_port, and auth_protocol "
-                "configuration options was deprecated in the Newton release "
-                "in favor of www_authenticate_uri. These options will be "
-                "removed in the S release.")
-            auth_host = conf.get('auth_host')
-            auth_port = int(conf.get('auth_port', 35357))
-            auth_protocol = conf.get('auth_protocol', 'https')
-
-            self._request_uri = '%s://%s:%s' % (auth_protocol, auth_host,
-                                                auth_port)
+        self._request_uri = conf.get(
+            'www_authenticate_uri', 'http://127.0.0.1:5000')
 
         # SSL
         insecure = strutils.bool_from_string(conf.get('insecure', False))
@@ -118,7 +100,7 @@ class S3Token(object):
     def _json_request(self, creds_json):
         headers = {'Content-Type': 'application/json'}
         try:
-            response = requests.post('%s/v2.0/s3tokens' % self._request_uri,
+            response = requests.post('%s/v3/s3tokens' % self._request_uri,
                                      headers=headers, data=creds_json,
                                      verify=self._verify,
                                      timeout=CONF.s3_token.timeout)
