@@ -15,11 +15,9 @@
 from unittest import mock
 import urllib.parse
 
-import fixtures
 from oslo_serialization import jsonutils
 import requests
 from requests_mock.contrib import fixture as rm_fixture
-from testtools import matchers
 import webob
 
 from keystonemiddleware import s3_token
@@ -42,7 +40,7 @@ class FakeApp(object):
 class S3TokenMiddlewareTestBase(utils.TestCase):
 
     TEST_WWW_AUTHENTICATE_URI = 'https://fakehost/identity'
-    TEST_URL = '%s/v2.0/s3tokens' % (TEST_WWW_AUTHENTICATE_URI, )
+    TEST_URL = '%s/v3/s3tokens' % (TEST_WWW_AUTHENTICATE_URI, )
 
     def setUp(self):
         super(S3TokenMiddlewareTestBase, self).setUp()
@@ -96,25 +94,6 @@ class S3TokenMiddlewareTestGood(S3TokenMiddlewareTestBase):
         self.assertTrue(req.path.startswith('/v1/AUTH_TENANT_ID'))
         self.assertEqual(req.headers['X-Auth-Token'], 'TOKEN_ID')
 
-    def test_authorized_http(self):
-        protocol = 'http'
-        host = 'fakehost'
-        port = 35357
-        self.requests_mock.post(
-            '%s://%s:%s/v2.0/s3tokens' % (protocol, host, port),
-            status_code=201, json=GOOD_RESPONSE)
-
-        self.middleware = (
-            s3_token.filter_factory({'auth_protocol': protocol,
-                                     'auth_host': host,
-                                     'auth_port': port})(FakeApp()))
-        req = webob.Request.blank('/v1/AUTH_cfa/c/o')
-        req.headers['Authorization'] = 'access:signature'
-        req.headers['X-Storage-Token'] = 'token'
-        req.get_response(self.middleware)
-        self.assertTrue(req.path.startswith('/v1/AUTH_TENANT_ID'))
-        self.assertEqual(req.headers['X-Auth-Token'], 'TOKEN_ID')
-
     def test_authorization_nova_toconnect(self):
         req = webob.Request.blank('/v1/AUTH_swiftint/c/o')
         req.headers['Authorization'] = 'access:FORCED_TENANT_ID:signature'
@@ -225,25 +204,3 @@ class S3TokenMiddlewareTestBad(S3TokenMiddlewareTestBase):
         s3_invalid_req = self.middleware._deny_request('InvalidURI')
         self.assertEqual(resp.body, s3_invalid_req.body)
         self.assertEqual(resp.status_int, s3_invalid_req.status_int)
-
-
-class S3TokenMiddlewareTestDeprecatedOptions(S3TokenMiddlewareTestBase):
-    def setUp(self):
-        super(S3TokenMiddlewareTestDeprecatedOptions, self).setUp()
-        self.conf = {
-            'auth_uri': self.TEST_WWW_AUTHENTICATE_URI,
-        }
-        self.logger = self.useFixture(fixtures.FakeLogger())
-        self.middleware = s3_token.S3Token(FakeApp(), self.conf)
-
-        self.requests_mock.post(self.TEST_URL,
-                                status_code=201,
-                                json=GOOD_RESPONSE)
-
-    def test_logs_warning(self):
-        req = webob.Request.blank('/')
-        self.middleware(req.environ, self.start_fake_response)
-        self.assertEqual(self.response_status, 200)
-        log = "Use of the auth_uri option was deprecated in the Queens " \
-            "release in favor of www_authenticate_uri."
-        self.assertThat(self.logger.output, matchers.Contains(log))
